@@ -53,6 +53,61 @@ my $factor        = 5;
 
 $F->cls('OFF');
 # if (0){
+
+print_it($F,'Color Mapping Test -> Red-Green-Blue');
+{
+    my $third = int($XX / 3);
+    $F->set_color(
+        {
+            'red'   => 255,
+            'green' => 0,
+            'blue'  => 0,
+        }
+    );
+    $F->rbox(
+        {
+            'filled' => 1,
+            'x'      => 0,
+            'y'      => 0,
+            'width'  => $third,
+            'height' => $YY
+        }
+    );
+    $F->set_color(
+        {
+            'red'   => 0,
+            'green' => 255,
+            'blue'  => 0,
+        }
+    );
+    $F->rbox(
+        {
+            'filled' => 1,
+            'x'      => $third,
+            'y'      => 0,
+            'width'  => $third,
+            'height' => $YY
+        }
+    );
+    $F->set_color(
+        {
+            'red'   => 0,
+            'green' => 0,
+            'blue'  => 255,
+        }
+    );
+    $F->rbox(
+        {
+            'filled' => 1,
+            'x'      => $third * 2,
+            'y'      => 0,
+            'width'  => $third,
+            'height' => $YY
+        }
+    );
+    sleep $factor;
+}
+
 print_it($F, 'Plotting Test');
 $s = time + $factor;
 while (time < $s) {
@@ -545,11 +600,11 @@ while (time < $s) {
     $F->replace_color(
         {
             'old_red'   => $r,
-              'old_green' => $g,
-              'old_blue'  => $b,
-              'new_red'   => $R,
-              'new_green' => $G,
-              'new_blue'  => $B
+            'old_green' => $g,
+            'old_blue'  => $b,
+            'new_red'   => $R,
+            'new_green' => $G,
+            'new_blue'  => $B
         }
     );
     ($r, $g, $b) = ($R, $G, $B);
@@ -562,11 +617,11 @@ while (time < $s) {
     my $image = $F->load_image(
         {
             'x'      => 0,
-              'y'      => 0,
-              'width'  => rand($XX),
-              'height' => rand($YY),
-              'center' => 3,
-              'file'   => 'images/testpattern.jpg'
+            'y'      => 0,
+            'width'  => rand($XX),
+            'height' => rand($YY),
+            'center' => 3,
+            'file'   => 'images/testpattern.jpg'
         }
     );
     $F->blit_write($image);
@@ -575,10 +630,10 @@ while (time < $s) {
 $image = $F->load_image(
     {
         'x'      => 0,
-          'y'      => 0,
-          'width'  => $XX,
-          'height' => $YY - $F->{'Y_CLIP'},
-          'file'   => 'images/testpattern.jpg'
+        'y'      => 0,
+        'width'  => $XX,
+        'height' => $YY - $F->{'Y_CLIP'},
+        'file'   => 'images/testpattern.jpg'
     }
 );
 $F->blit_write($image);
@@ -589,10 +644,10 @@ print_it($F, 'Testing Image blitting');
 $image = $F->load_image(
     {
         'x'      => 0,
-          'y'      => 0,
-          'width'  => int($XX/3),
-          'height' => int($YY/3),
-          'file'   => 'images/RWBY_Logo.jpg'
+        'y'      => 0,
+        'width'  => int($XX/3),
+        'height' => int($YY/3),
+        'file'   => 'images/RWBY_Logo.jpg'
     }
 );
 $s = time + $factor;
@@ -603,15 +658,27 @@ while (time < $s) {
 }
 
 print_it($F, "Testing Image rotate");
-$image = $F->load_image(
-    {
-        'x'      => 0,
-          'y'      => 0,
-          'width'  => int($XX/3),
-          'height' => int($YY/3),
-          'file'   => 'images/RWBY_Oh_No.jpg'
-    }
-);
+if ($YY<=192) {
+    $image = $F->load_image(
+        {
+            'x'      => 0,
+            'y'      => 0,
+            'width'  => int($YY*.75),
+#            'height' => int($YY/3),
+            'file'   => 'images/RWBY_Oh_No.jpg'
+        }
+    );
+} else {
+    $image = $F->load_image(
+        {
+            'x'      => 0,
+            'y'      => 0,
+            'width'  => int($XX/3),
+            'height' => int($YY/3),
+            'file'   => 'images/RWBY_Oh_No.jpg'
+        }
+    );
+}
 $angle = 0;
 $s = time + ($factor * 2);
 while (time < $s) {
@@ -630,27 +697,48 @@ while (time < $s) {
     $angle = 0 if ($angle >= 360);
 }
 
-$image = $F->load_image(
-    {
-        'x'      => 0,
-          'y'      => 0,
-          'width'  => int($XX/3),
-          'height' => int($YY/3),
-          'file'   => 'images/RWBY_Faces.png'
-    }
-);
+if ($XX<=256) {
+    $image = $F->load_image(
+        {
+            'x'      => 0,
+            'y'      => 0,
+            'width'  => $XX,
+            'height' => $YY,
+            'file'   => 'images/RWBY_Faces.png'
+        }
+    );
+} else {
+    $image = $F->load_image(
+        {
+            'x'      => 0,
+            'y'      => 0,
+            'width'  => int($XX/3),
+            'height' => int($YY/3),
+            'file'   => 'images/RWBY_Faces.png'
+        }
+    );
+}
 $s = time + $factor;
 $angle = 0; # Just re-using this variable
+$image = $F->blit_transform(
+    {
+        'scale' => {
+            'width' => int($XX * .6),
+            'height' => int($YY * .6)
+        },
+        'blit_data' => $image
+    }
+);
 while (time < $s) {
     foreach my $dir (qw(normal horizontal normal vertical)) {
         my $rot = $F->blit_transform(
             {
                 'flip'      => $dir,
-                  'blit_data' => $image
+                'blit_data' => $image
             }
         );
-        $rot->{'x'} = abs(($XX - $rot->{'width'})/2);
-        $rot->{'y'} = abs(($YY - $rot->{'height'})/2);
+        $rot->{'x'} = abs(($XX - $rot->{'width'})  / 2);
+        $rot->{'y'} = abs(($YY - $rot->{'height'}) / 2);
         print_it($F, "Testing Image flip $dir");
         $F->blit_write($rot);
         sleep .5 unless($angle);
@@ -676,14 +764,14 @@ closedir($DIR);
 foreach my $info (@list) {
     next unless ($info =~ /\.gif$/i);
     for $angle (0 .. 1) {
-        if ($angle) {
+        if ($angle || $XX <= 256) {
             print_it($F, "Testing Animated Image Display of '$info' fullscreen");
             $image = $F->load_image(
                 {
                     'width'  => $XX,
-                      'height' => $YY - $F->{'Y_CLIP'},
-                      'file'   => "images/$info",
-                      'center' => 3
+                    'height' => $YY - $F->{'Y_CLIP'},
+                    'file'   => "images/$info",
+                    'center' => 3
                 }
             );
         } else {
@@ -691,7 +779,7 @@ foreach my $info (@list) {
             $image = $F->load_image(
                 {
                     'file'   => "images/$info",
-                      'center' => 3
+                    'center' => 3
                 }
             );
         }
@@ -713,6 +801,7 @@ foreach my $info (@list) {
                 }
             }
         }
+        last if ($XX <= 256);
     }
 }
 $F->clip_reset();
@@ -748,7 +837,8 @@ sub print_it {
         $center_y = (($YY - $b->{'pheight'}) / 2) + $b->{'pheight'};
         $fb->normal_mode();
     } else {
-        print "$message\n";
+        system('clear');
+        print STDERR "$message\n";
     }
 } ## end sub print_it
 
