@@ -11,10 +11,21 @@ use Graphics::Framebuffer;
 use Time::HiRes qw(sleep time);
 # use Data::Dumper::Simple;$Data::Dumper::Sortkeys=1;
 
+my $args = join('',@ARGV);
+
+my $file = 0;
+$file = 1 if ($args =~ /file/i);
+
+my $dev = 0;
+if ($args =~ /(\d+)/) {
+    ($dev) = $1;
+}
+
 my $f = Graphics::Framebuffer->new(
-#    'FB_DEVICE'   => '/dev/fb1',
+    'FB_DEVICE'   => "/dev/fb$dev",
     'SPLASH'      => 0,
-    'SHOW_ERRORS' => 1
+    'SHOW_ERRORS' => 1,
+    'FILE_MODE'   => $file
 );
 
 system('clear');
@@ -24,7 +35,7 @@ $f->cls('OFF');
 my %p = (
     'width'  => $f->{'XRES'},
     'height' => $f->{'YRES'},
-    'file'   => $ARGV[0]
+    'file'   => $ARGV[-1]
 );
 # $p{'noscale'} = 1 if ($ARGV[0] =~ /\.gif$/i);
 my $image = $f->load_image(\%p);
